@@ -6,8 +6,9 @@ from time import sleep
 
 
 class PreCheck:
-    def __init__(self, server_config_path: str):
+    def __init__(self, server_config_path: str, image_config_path: str):
         server_config = yaml.safe_load(open(server_config_path))
+        image_config = yaml.safe_load(open(image_config_path))
         try:
             self.hyperdata_addr = server_config["hyperdata_addr"]
             self.automl_addr = server_config["automl_addr"]
@@ -15,9 +16,9 @@ class PreCheck:
             self.user_id = server_config["user_id"]
             self.user_password = server_config["user_password"]
             self.project_name = server_config["project_name"]
-            self.train_input_columns = server_config["train_input_columns"]
+            self.train_input_columns = image_config["train_input_columns"]
             self.train_do_name = server_config["train_do_name"]
-            self.inference_input_columns = server_config["inference_input_columns"]
+            self.inference_input_columns = image_config["inference_input_columns"]
             self.inference_do_name = server_config["inference_do_name"]
         except KeyError as e:
             print(f'Cannot found "{str(e)}" in server_config.yaml')
@@ -165,7 +166,7 @@ class PredefinedAITemplateTest:
     def __init__(self, server_config_path: str, image_config_path: str):
         # replace test params
         server_config = yaml.safe_load(open(server_config_path))
-        self.pre_check = PreCheck(server_config_path)
+        self.pre_check = PreCheck(server_config_path, image_config_path)
         self.pre_check.run()
 
         self.automl_addr = server_config["automl_addr"]
